#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Dec 12 17:05:53 2020

@author: johanna_anjar
"""
#Bibliotek 
#Bibliotek är hjälpfunktioner som behövs för att programmet ska fungera, här installerar vi tre stycken
import pandas as pd  #Läsa och skriva fildata
import numpy as np   #Diverse matematiska funktioner
import matplotlib.pyplot as plt  #Plottar och diagram

#Läs in datan
#Datafilen måste ligga i samma mapp som programet.
file = 'kornstorlek.xlsx' #Namnet på filen med din kornstorleksdata. Ändrar du filnamnet måste du ändra här också. 
data = pd.read_excel(file)

#Lägg in datan från excel-filen i arrayer
rev_sikt_mm = data['Sikt_mm'].values #Värdena i kolumnen "Sikt_mm" hamnar i arrayen "sikt_mm"
rev_vikt = data['Vikt_g'].values #Värdena i kolumnen "Vikt_g" hamnar i arrayen "vikt"

#Vi vill ha siktarna sorterade från minsta till största istället så vi vänder på bägge arrayerna
vikt = np.flip(rev_vikt)
sikt_mm = np.flip(rev_sikt_mm)

#Beräkningar

#Beräkna totalvikten
#Den här funktionen beräknar provets totalvikt genom att summera vikterna för varje sikt
def totalvikt(vikt):
    sum_vikt = 0
    for i in range(0, len(vikt)):   
        sum_vikt += vikt[i] 
    return sum_vikt
    
print('Totalvikten för provet är:', totalvikt(vikt), 'g') #Skriver ut resultatet på skärmen

#Omvandla vikten för varje sikt till procent av totalvikten
vikt_procent = 100 * (vikt / totalvikt(vikt)) 

#Kumulativa värden
length = len(vikt_procent)
kumulativ = np.zeros([length])
kumulativ[0] = 0
kumulativ[1] = vikt_procent[0]
for i in range(2, length): 
    kumulativ[i] += kumulativ[i-1] + vikt_procent[i-1]
    
#Skriv resultat till fil
#I en tabell blir det mest logiskt med datan från den grövsta sikten överst, eftersom det är så vi vägde innehållet i labbet, så först vänder vi på alla arrayer igen.
rev_kumulativ = np.flip(kumulativ)
rev_vikt_procent = np.flip(vikt_procent)
data = {'Sikt': rev_sikt_mm, 'Vikt': rev_vikt, 
        'Vikt_procent': rev_vikt_procent, 'Kumulativ_procent': rev_kumulativ}
df = pd.DataFrame(data)

df.to_excel('output.xlsx')

#Plotta resultaten
kumulativ = kumulativ[1: length]  #vi vill inte ha med siktbottnen så vi tar bort den från arrayen
sikt_mm = sikt_mm[1: length] #vi vill inte ha med siktbottnen så vi tar bort den från arrayen
plt.close('all')
plt.figure(1)
plt.plot(sikt_mm, kumulativ, 'b*-')
plt.xscale('log')
plt.ylim(0, 100)
plt.xlim(0.001, 100)
plt.title('Kumulativ kornfördelningskurva')
plt.xlabel('Maskvidd (mm)')
plt.ylabel('Viktprocent finare än maskvidden')
plt.grid(True, which="both", ls="-")
plt.show()
